@@ -448,22 +448,20 @@ periods <- function(
 #' 
 #' transitions(events, format = "heatmap")
 #' 
-#' events <- data.frame(event = c(
-#'   "AWA","N1","N2","N2", "N3","N3",
-#'   "REM","N2","REM","REM", "N2","REM","AWA"))
+#' # 3 Dimensions sleep transitions
+#' levels(events$event)[levels(events$event)=="N1"] <- "NREM"
+#' levels(events$event)[levels(events$event)=="N2"] <- "NREM"
+#' levels(events$event)[levels(events$event)=="N3"] <- "NREM"
 #' 
-#' events$begin <- as.POSIXlt(seq(from = 0, to = 30*(nrow(events)-1), by = 30),origin = "1970-01-01")
-#' 
-#' events$end <- as.POSIXlt(seq(from = 30, to = 30*nrow(events), by = 30), origin = "1970-01-01")
-#' 
-#' transitions(events)
-#' 
-#' transitions(events, format = "dataframe")
-#' 
-#' transitions(events, format = "heatmap")
+#' round(
+#'   transitions(
+#'     events, 
+#'     format = "dataframe")/(
+#'       sum(transitions(events)))*100,2)
+#'       
 transitions <- function(
     hypnogram,
-    stages = c("AWA", "REM", "N1", "N2", "N3"),
+    stages = c("AWA", "REM", "N1", "N2", "N3", "NREM"),
     format = "vector"){
   
   hypnogram$event <- as.character(hypnogram$event)
